from PIL import Image
import os
import pathlib
from .constants import *


def calcDP(px):
    index = -1
    if px in SIZES_PX:
        index = SIZES_PX.index(px)
    else:
        for item in SIZES_PX:
            if item > px:
                index = SIZES_PX.index(item)
                break

    if index == -1:
        index = len(SIZES_PX) - 1

    return px / (SIZES_DPI[index] / 160)


def calcNewSizes(dp):
    res = []
    for item in SCALING:
        res.append(int(item * dp))
    return res


def getImageFilesList():
    files = []
    for file in os.listdir("."):
        if isImage(file):
            files.append(file)
    return files


def isImage(name):
    if os.path.isfile(name):
        file_parts = pathlib.Path(name)
        if file_parts.suffix.removeprefix(".") in SUPPORTED_FORMATS:
            return True
    return False


def checkImageNameForSave(name: str):
    # in android drawables images can't start with numbers
    # and is better they haven't capitalize words
    name = name.lower()

    if name[0].isnumeric():
        name = '_' + name

    return name


def createNewImage(img_path):
    img = Image.open(img_path)
    x, y = img.size
    ratio = x / y

    new_xs = calcNewSizes(calcDP(x))
    new_ys = []
    for item in new_xs:
        new_ys.append(int(item / ratio))

    for i in range(len(SCALING)):
        root = "Drawable"
        folder = "drawable-" + DRAWABLE_SIZE_NAMES[i]
        name = checkImageNameForSave(img_path)
        path = os.path.join(root, folder, name)

        try:
            pathlib.Path(os.path.join(root, folder)).mkdir(parents=True, exist_ok=True)
            new_img = img.resize((new_xs[i], new_ys[i]))
            new_img.save(checkImageNameForSave(path))
        except Exception as ex:
            print(ex)



from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'drawable image creator'
LONG_DESCRIPTION = 'prepare images for use in android studio projects'
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="drimg",
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="hojjat-faryabi",
    author_email="hojjat.faryabi@gmail.com",
    url="https://github.com/hojjat-faryabi/drawable_image",
    license='MIT',
    packages=find_packages(),
    install_requires=['Pillow', 'click'],
    entry_points={
        'console_scripts': [
            'drimg = drimg.__main__:main'
        ]
    },
    keywords=['image', 'drawable', 'android', 'android-studio', 'drimg'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 3",
    ]
)



import click
from .functions import *


@click.command()
@click.argument("file_name", nargs=1, required=False, type=str)
@click.option(
    "--all",
    "-a",
    help="convert all images in current directory ",
    is_flag=True
)
def commandHandler(file_name, all):
    if file_name:
        # change only one image
        # print(file_name)
        if isImage(file_name):
            print(file_name, end="  ")
            createNewImage(file_name)
            print("Done")
        else:
            print("file '", file_name, "' not exist or is not a image!")
    elif all:
        # print("all")
        images = getImageFilesList()

        for i in range(len(images)):
            print(str(i + 1) + "  " + images[i], end="  ")
            createNewImage(images[i])
            print("Done")
    else:
        click.echo('please use drimg --help')
